orcid\_api\.models package
==========================

Submodules
----------

orcid\_api\.models\.activities\_summary module
----------------------------------------------

.. automodule:: orcid_api.models.activities_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.address module
----------------------------------

.. automodule:: orcid_api.models.address
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.amount module
---------------------------------

.. automodule:: orcid_api.models.amount
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.authorization\_url module
---------------------------------------------

.. automodule:: orcid_api.models.authorization_url
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.bulk\_element module
----------------------------------------

.. automodule:: orcid_api.models.bulk_element
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.citation module
-----------------------------------

.. automodule:: orcid_api.models.citation
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.contributor module
--------------------------------------

.. automodule:: orcid_api.models.contributor
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.contributor\_attributes module
--------------------------------------------------

.. automodule:: orcid_api.models.contributor_attributes
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.contributor\_email module
---------------------------------------------

.. automodule:: orcid_api.models.contributor_email
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.contributor\_orcid module
---------------------------------------------

.. automodule:: orcid_api.models.contributor_orcid
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.country module
----------------------------------

.. automodule:: orcid_api.models.country
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.created\_date module
----------------------------------------

.. automodule:: orcid_api.models.created_date
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.credit\_name module
---------------------------------------

.. automodule:: orcid_api.models.credit_name
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.day module
------------------------------

.. automodule:: orcid_api.models.day
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.disambiguated\_organization module
------------------------------------------------------

.. automodule:: orcid_api.models.disambiguated_organization
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.education module
------------------------------------

.. automodule:: orcid_api.models.education
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.education\_summary module
---------------------------------------------

.. automodule:: orcid_api.models.education_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.educations module
-------------------------------------

.. automodule:: orcid_api.models.educations
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.employment module
-------------------------------------

.. automodule:: orcid_api.models.employment
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.employment\_summary module
----------------------------------------------

.. automodule:: orcid_api.models.employment_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.employments module
--------------------------------------

.. automodule:: orcid_api.models.employments
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.external\_i\_ds module
------------------------------------------

.. automodule:: orcid_api.models.external_i_ds
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.external\_id module
---------------------------------------

.. automodule:: orcid_api.models.external_id
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding module
----------------------------------

.. automodule:: orcid_api.models.funding
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_contributor module
-----------------------------------------------

.. automodule:: orcid_api.models.funding_contributor
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_contributor\_attributes module
-----------------------------------------------------------

.. automodule:: orcid_api.models.funding_contributor_attributes
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_contributors module
------------------------------------------------

.. automodule:: orcid_api.models.funding_contributors
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_group module
-----------------------------------------

.. automodule:: orcid_api.models.funding_group
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_summary module
-------------------------------------------

.. automodule:: orcid_api.models.funding_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.funding\_title module
-----------------------------------------

.. automodule:: orcid_api.models.funding_title
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.fundings module
-----------------------------------

.. automodule:: orcid_api.models.fundings
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.fuzzy\_date module
--------------------------------------

.. automodule:: orcid_api.models.fuzzy_date
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.group\_id\_record module
--------------------------------------------

.. automodule:: orcid_api.models.group_id_record
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.group\_id\_records module
---------------------------------------------

.. automodule:: orcid_api.models.group_id_records
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.item module
-------------------------------

.. automodule:: orcid_api.models.item
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.items module
--------------------------------

.. automodule:: orcid_api.models.items
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.keyword module
----------------------------------

.. automodule:: orcid_api.models.keyword
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.last\_modified\_date module
-----------------------------------------------

.. automodule:: orcid_api.models.last_modified_date
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.month module
--------------------------------

.. automodule:: orcid_api.models.month
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.notification module
---------------------------------------

.. automodule:: orcid_api.models.notification
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.notification\_permission module
---------------------------------------------------

.. automodule:: orcid_api.models.notification_permission
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.organization module
---------------------------------------

.. automodule:: orcid_api.models.organization
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.organization\_address module
------------------------------------------------

.. automodule:: orcid_api.models.organization_address
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.organization\_defined\_funding\_sub\_type module
--------------------------------------------------------------------

.. automodule:: orcid_api.models.organization_defined_funding_sub_type
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.other\_name module
--------------------------------------

.. automodule:: orcid_api.models.other_name
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.peer\_review module
---------------------------------------

.. automodule:: orcid_api.models.peer_review
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.peer\_review\_group module
----------------------------------------------

.. automodule:: orcid_api.models.peer_review_group
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.peer\_review\_summary module
------------------------------------------------

.. automodule:: orcid_api.models.peer_review_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.peer\_reviews module
----------------------------------------

.. automodule:: orcid_api.models.peer_reviews
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.person\_external\_identifier module
-------------------------------------------------------

.. automodule:: orcid_api.models.person_external_identifier
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.publication\_date module
--------------------------------------------

.. automodule:: orcid_api.models.publication_date
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.researcher\_url module
------------------------------------------

.. automodule:: orcid_api.models.researcher_url
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.source module
---------------------------------

.. automodule:: orcid_api.models.source
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.source\_client\_id module
---------------------------------------------

.. automodule:: orcid_api.models.source_client_id
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.source\_name module
---------------------------------------

.. automodule:: orcid_api.models.source_name
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.source\_orcid module
----------------------------------------

.. automodule:: orcid_api.models.source_orcid
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.subtitle module
-----------------------------------

.. automodule:: orcid_api.models.subtitle
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.title module
--------------------------------

.. automodule:: orcid_api.models.title
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.transient\_non\_empty\_string module
--------------------------------------------------------

.. automodule:: orcid_api.models.transient_non_empty_string
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.translated\_title module
--------------------------------------------

.. automodule:: orcid_api.models.translated_title
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.url module
------------------------------

.. automodule:: orcid_api.models.url
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work module
-------------------------------

.. automodule:: orcid_api.models.work
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work\_bulk module
-------------------------------------

.. automodule:: orcid_api.models.work_bulk
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work\_contributors module
---------------------------------------------

.. automodule:: orcid_api.models.work_contributors
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work\_group module
--------------------------------------

.. automodule:: orcid_api.models.work_group
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work\_summary module
----------------------------------------

.. automodule:: orcid_api.models.work_summary
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.work\_title module
--------------------------------------

.. automodule:: orcid_api.models.work_title
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.works module
--------------------------------

.. automodule:: orcid_api.models.works
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.models\.year module
-------------------------------

.. automodule:: orcid_api.models.year
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: orcid_api.models
    :members:
    :undoc-members:
    :show-inheritance:
